info: add initial code to dump queue state when sent SIGHUP

Signed-off-by: Phillip Lougher <phillip@squashfs.org.uk>
diff --git a/squashfs-tools/mksquashfs.c b/squashfs-tools/mksquashfs.c
index b60d118..4aa0d93 100644
--- a/squashfs-tools/mksquashfs.c
+++ b/squashfs-tools/mksquashfs.c
@@ -3987,9 +3987,10 @@
 	signal(SIGINT, sighandler);
 	signal(SIGUSR1, sighandler);
 
 	/* block SIGQUIT this is handled by the info thread */
 	sigemptyset(&sigmask);
 	sigaddset(&sigmask, SIGQUIT);
+	sigaddset(&sigmask, SIGHUP);
 	if(pthread_sigmask(SIG_BLOCK, &sigmask, &old_mask) == -1)
 		BAD_ERROR("Failed to set signal mask in intialise_threads\n");
 
@@ -4724,7 +4725,7 @@
 
 
 #define VERSION() \
-	printf("mksquashfs version 4.2-git (2013/04/16)\n");\
+	printf("mksquashfs version 4.2-git (2013/04/21)\n");\
 	printf("copyright (C) 2013 Phillip Lougher "\
 		"<phillip@squashfs.org.uk>\n\n"); \
 	printf("This program is free software; you can redistribute it and/or"\
@@ -3987,9 +3987,10 @@
 	signal(SIGUSR1, sighandler);
 
-	/* block SIGQUIT this is handled by the info thread */
+	/* block SIGQUIT and SIGHUP, these are handled by the info thread */
 	sigemptyset(&sigmask);
 	sigaddset(&sigmask, SIGQUIT);